<!-- 
Author(s): Shibaji Chakraborty, Xueling Shi

Disclaimer:
SCUBAS is under the MIT license found in the root directory LICENSE.md 
Everyone is permitted to copy and distribute verbatim copies of this license 
document.

This version of the MIT Public License incorporates the terms
and conditions of MIT General Public License.
-->

::: scubas.utils.RecursiveNamespace
    handler: python
    options:
      members:
        - map_entry
      show_root_heading: true
      show_source: true

::: scubas.utils.frexp102str
    options:
      show_root_heading: true
      show_source: true
      
::: scubas.utils.fft
    options:
      show_root_heading: true
      show_source: true
      
::: scubas.utils.ifft
    options:
      show_root_heading: true
      show_source: true